==> qmmp_1.4.3.orig.tar.bz2: qmmp-1.4.3/src/plugins/General/statusicon/translations/statusicon_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Durum Simgesi Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Saydamlık:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation type="unfinished">32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Standart simgeleri kullan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="73"/>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="75"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="76"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="78"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="120"/>
        <source>Stopped</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="145"/>
        <source>Now Playing</source>
        <translation>Şimdi Oynatılıyor</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="29"/>
        <source>Status Icon Plugin</source>
        <translation>Durum Simgesi Eklentisi</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation>Durum Simgesi Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp Durum Simgesi Eklentisi</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Written by:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-1.5.4.tar.bz2: qmmp-1.5.4/src/plugins/General/statusicon/translations/statusicon_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Status Icon Plugin Settings</source>
        <translation>Durum Simgesi Eklenti Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>Balloon message</source>
        <translation>Balon mesaj</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <location filename="../settingsdialog.ui" line="105"/>
        <source>Delay, ms:</source>
        <translation>Gecikme, ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="79"/>
        <source>Tooltip</source>
        <translation>Araç İpucu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="91"/>
        <source>Try to split file name when no tag</source>
        <translation>Etiket olmadığı zaman dosya adını bölmeyi deneyin</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="98"/>
        <source>Show progress bar</source>
        <translation>İlerleme çubuğunu göster</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Transparency:</source>
        <translation>Saydamlık:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="165"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="174"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="214"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="225"/>
        <source>Edit template</source>
        <translation>Şablonu düzenle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="250"/>
        <source>Use standard icons</source>
        <translation>Standart simgeleri kullan</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Tooltip Template</source>
        <translation>Araç İpucu Şablonu</translation>
    </message>
</context>
<context>
    <name>StatusIcon</name>
    <message>
        <location filename="../statusicon.cpp" line="71"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="72"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="73"/>
        <source>Stop</source>
        <translation>Durdur</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="75"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="76"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="78"/>
        <source>Exit</source>
        <translation>Çık</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="120"/>
        <source>Stopped</source>
        <translation>Durduruldu</translation>
    </message>
    <message>
        <location filename="../statusicon.cpp" line="145"/>
        <source>Now Playing</source>
        <translation>Şimdi Oynatılıyor</translation>
    </message>
</context>
<context>
    <name>StatusIconFactory</name>
    <message>
        <location filename="../statusiconfactory.cpp" line="29"/>
        <source>Status Icon Plugin</source>
        <translation>Durum Simgesi Eklentisi</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="49"/>
        <source>About Status Icon Plugin</source>
        <translation>Durum Simgesi Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="50"/>
        <source>Qmmp Status Icon Plugin</source>
        <translation>Qmmp Durum Simgesi Eklentisi</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="51"/>
        <source>Written by:</source>
        <translation>Tarafından yazılmıştır:</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="52"/>
        <source>Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../statusiconfactory.cpp" line="53"/>
        <source>Artur Guzik &lt;a.guzik88@gmail.com&gt;</source>
        <translation>Artur Guzik &lt;a.guzik88@gmail.com&gt;</translation>
    </message>
</context>
</TS>
